@@ -4,7 +4,8 @@ from skimage.transform import resize, rescale
 
 import numpy as np
 
-from autoarray.structures import grids, arrays
+from autoarray.structures import arrays
+from autoarray.structures import grids
 from autoarray.util import array_util
 from autoarray import exc
 
